@@ -41,41 +41,6 @@ setGeneric(name = "unit_objects",
 setGeneric(name = "unitLogLik",
            def = function(object, ...) standardGeneric("unitLogLik"))
 
-
-#' @rdname unitlogLik-deprecated
-#' @name unitlogLik-deprecated
-#' @title (Deprecated) Extract log likelihood of units of panel models
-#' @description
-#' `r lifecycle::badge("deprecated")`
-#'
-#' In future versions, this generic is being replaced with [unitLogLik()].
-#'
-#' \code{unitlogLik()} is a generic function that extracts the log
-#' likelihood for each unit of panel objects returned by panel modeling functions.
-#' While the \code{numeric} value with the log likelihood for the entire panel
-#' is useful and possible via S4 methods \code{logLik()}, the contributions to it
-#' by panel units can be implemented via \code{unitlogLik()}.
-#' @param object an object for which log likelihood values for units can be extracted.
-#' @param ... additional arguments.
-#' @details This is a generic function: methods can be defined for it.
-#' @return Log likelihood extracted for each unit of the panel model \code{object}.
-#'
-#' When given objects of class \code{pfilterd.ppomp}, \code{unitloglik()} returns a \code{numeric} vector.
-#' @examples
-#' # filter, which generates log likelihoods
-#' pfrw <- pfilter(panelRandomWalk(),Np=10)
-#'
-#' # extract log likelihood for each panel unit
-#' unitlogLik(pfrw)
-#'
-#' @keywords internal
-#' @seealso \link{pfilter}
-#' @author Carles \Breto
-#' @aliases unitlogLik
-#' @export
-setGeneric(name = "unitlogLik",
-           def = function(object, ...) standardGeneric("unitlogLik"))
-
 #' Extract unit-specific parameters from a panelPomp object
 #'
 #' This function is used to extract the unit-specific parameters from a
